<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
          "DTD/xhtml1-strict.dtd">
<html xmlns:t="http://twistedmatrix.com/ns/twisted.web.template/0.1">
  <head>
    <title t:render="title">Something</title>
    <link rel="stylesheet" type="text/css" href="apidocs.css"/>
  </head>
  <body>
    <h1 t:render="heading">Heading</h1>
    <t:transparent t:render="index">
        <a>
          <t:attr name="name" t:render="letter" />
        </a>
        <h2 t:render="letter" />
        <p class="letterlinks" t:render="letterlinks" />
        <ul>
          <li t:render="names" />
        </ul>
    </t:transparent>
  </body>
</html>
