<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
          "DTD/xhtml1-strict.dtd">
<html xmlns:t="http://twistedmatrix.com/ns/twisted.web.template/0.1" t:render="all">
  <head>
    <title><t:slot name="title">Something</t:slot> : API documentation</title>
    <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
    <link rel="stylesheet" type="text/css" href="apidocs.css" />
    <script t:render="ifusesorttable" type="text/javascript"
            src="sorttable.js"></script>
    <script t:render="pydoctorjs" type="text/javascript"
            src="pydoctor.js"></script>
  </head>
  <body>
    <t:slot name="heading"><h1>Heading</h1></t:slot>
    <p>
      <span id="part"><t:slot name="part">Part of something</t:slot></span>
      <a t:render="source">View Source</a>
      <a t:render="inhierarchy">View In Hierarchy</a>
    </p>
    <div>
      <t:slot name="extras">
        A docstring.
      </t:slot>
    </div>
    <div class="docstring">
      <t:slot name="docstring">
        A docstring.
      </t:slot>
    </div>

    <p t:render="splittingLinks">
      <a id="showSplitLink" href="#" onclick="showSplit()" class="jslink">Split Table into Classes</a>
      <a id="showBigLink" href="#" onclick="showBig()" class="jslink">Show Methods in One Table</a>
    </p>
    <div id="splitTables">
      <t:slot name="mainTable" />
      <t:invisible t:render="baseTables">
        <p>
          Inherited from <t:slot name="baseName" />:
        </p>
        <t:slot name="baseTable" />
      </t:invisible>
    </div>
    <div id="bigTable" t:render="bigTable">
    </div>
    <t:slot name="packageInitTable" />

    <t:slot name="childlist" />
    <address>
      <a href="index.html">API Documentation</a> for <t:slot name="project">Some
        Project</t:slot>, generated by <a href="https://launchpad.net/pydoctor/">pydoctor</a> at <t:slot name="buildtime">some time</t:slot>.
    </address>
  </body>
</html>
